import { GroupedEvent } from '@castore/core';
import type { EventDetail, EventsQueryOptions, EventStorageAdapter, EventStoreContext, ListAggregateIdsOptions, ListAggregateIdsOutput, OptionalTimestamp, PushEventOptions } from '@castore/core';
declare type AggregateId = {
    type: 'UUID' | 'ULID';
} | {
    type: 'VARCHAR';
    length: number;
};
export declare type ParsedPageToken = {
    limit?: number;
    initialEventAfter?: string | undefined;
    initialEventBefore?: string | undefined;
    reverse?: boolean | undefined;
    lastEvaluatedKey?: {
        aggregateId: string;
        initialEventTimestamp: string;
    } | undefined;
};
export declare class PostgresEventStorageAdapter implements EventStorageAdapter {
    private _sql;
    private _tableName;
    constructor({ connectionString, tableName, }?: {
        connectionString?: string;
        tableName?: string;
    });
    private static createClient;
    static createEventTable({ connectionString, tableName, idType, aggregateNameLength, aggregateId, versionType, typeLength, }?: {
        connectionString?: string;
        tableName?: string;
        idType?: 'BIGSERIAL' | 'SERIAL';
        aggregateNameLength?: number;
        aggregateId?: AggregateId;
        versionType?: 'BIGINT' | 'INTEGER';
        typeLength?: number;
    }): Promise<{
        tableName: string;
    }>;
    static dropEventTable({ connectionString, tableName, }: {
        connectionString?: string;
        tableName?: string;
    }): Promise<void>;
    private toEventDetail;
    pushEvent(eventDetail: OptionalTimestamp<EventDetail>, options: PushEventOptions): Promise<{
        event: EventDetail;
    }>;
    getEvents(aggregateId: string, context: EventStoreContext, options?: EventsQueryOptions): Promise<{
        events: EventDetail[];
    }>;
    pushEventGroup(options: {
        force?: boolean;
    }, groupedEvents_0: GroupedEvent<{
        payload?: unknown;
        metadata?: unknown;
        type: string;
        aggregateId: string;
        version: number;
        timestamp: string;
    }>, ...groupedEvents: GroupedEvent<{
        payload?: unknown;
        metadata?: unknown;
        type: string;
        aggregateId: string;
        version: number;
        timestamp: string;
    }>[]): Promise<{
        eventGroup: {
            event: EventDetail;
        }[];
    }>;
    groupEvent(eventDetail: OptionalTimestamp<EventDetail>): GroupedEvent;
    private parseInputs;
    listAggregateIds(context: EventStoreContext, options?: ListAggregateIdsOptions): Promise<ListAggregateIdsOutput>;
}
export {};
//# sourceMappingURL=adapter.d.ts.map